#!/usr/bin/python3

# Key: d6c60c8e688e0afa7f49416897aadc1f
# Encryption method: AES-128-ECB

# Note: Pre-treatment of the base64 string may be necessary to make it usable by some base64 decoding methods.
#   - All occurrences of "-" (minus) must be changed to "+" (plus)
#   - All occurrences of "_" (underscore) must be changed to "/" (slash)
#   - All occurrences of "%20%20" must be removed or converted to carriage return + linefeed or just linefeed.
#   - The length of the string, after whitespace has been removed, must be evenly divisible by 4. If it is not,
#     add one or two "=" (equals) characters to make it evenly divisible by 4.

# "pip3 install pycryptodome" for Crypto.Cipher

import binascii
from base64 import b64decode
from base64 import b64encode
from Crypto.Cipher import AES

BS = 16 # 128 bits / 16 bytes
pad = lambda s: s + (BS - len(s) % BS) * chr(BS - len(s) % BS) 
unpad = lambda s : s[0:-ord(s[-1])]

class AESCipher:
    def __init__(self, key):
        self.key = binascii.unhexlify(key)

    def encrypt(self, raw):
        # This function has not been tested.
        raw = pad(raw)
        #cipher = AES.new(self.key, AES.MODE_ECB, iv) # not executed -- aes-128-ecb does not use an initialization vector.
        cipher = AES.new(self.key, AES.MODE_ECB)
        return b64encode(cipher.encrypt(raw))

    def decrypt(self, enc):
        enc = b64decode(enc)
        #cipher = AES.new(self.key, AES.MODE_ECB, iv) # not executed -- aes-128-ecb does not use an initialization vector.
        cipher = AES.new(self.key, AES.MODE_ECB)
        return unpad(cipher.decrypt(enc).decode('utf8'))

def standardizeBase64(nonstandardBase64):
    # All occurrences of "-" (minus) must be changed to "+" (plus)
    nonstandardBase64 = nonstandardBase64.replace('-', '+')
    # All occurrences of "_" (underscore) must be changed to "/" (slash)
    nonstandardBase64 = nonstandardBase64.replace('_', '/')
    # All occurrences of "%20%20" must be removed or converted to carriage return + linefeed or just linefeed.
    nonstandardBase64 = nonstandardBase64.replace('%20%20', '')
    # The length of the string, after whitespace has been removed, must be evenly divisible by 4. If it is not,
    # add one or two "=" (equals) characters to make it evenly divisible by 4.
    nonstandardBase64 += '=' * ((4 - (len(nonstandardBase64) % 4)) % 4);
    return nonstandardBase64

key = "d6c60c8e688e0afa7f49416897aadc1f" # 128-bit/16-byte key, represented as series of sixteen hex doubles

atdataEqsValue = "AeZFhZnm_ytYdj06wE5ikO4vPv302-SG9Osx_itiNbxF4gIY3CHdBpvpxd6Jaxvx%20%207i8-_fTb5Ib06zH-K2I1vEXiAhjcId0Gm-nF3olrG_HuLz799NvkhvTrMf4rYjW8%20%20rJmJDtsRTiTCWYfZfF6SDcHuTfwpOhubzIEAFNIeJRoOtRe-zev31MASpLRr2A_g%20%20wGPEJDvSZnokppAKPaWe2w"

b64CipherText = standardizeBase64(atdataEqsValue)
print('URL-friendly EQS:', atdataEqsValue)
print('Standardized B64:', b64CipherText)
clearText = AESCipher(key).decrypt(b64CipherText)
print('Clear text:', clearText)

